import request from '@/utils/request'
// 查询RoHS 测试数据，支持镉、铅、汞、铬、溴、氯检测列表
export function listData(query) {
  return request({
    url: '/qc/data/list',
    method: 'get',
    params: query
  })
}

// 查询RoHS 测试数据，支持镉、铅、汞、铬、溴、氯检测详细
export function getData(id) {
  return request({
    url: '/qc/data/' + id,
    method: 'get'
  })
}

// 新增RoHS 测试数据，支持镉、铅、汞、铬、溴、氯检测
export function addData(data) {
  return request({
    url: '/qc/data',
    method: 'post',
    data: data
  })
}

// 修改RoHS 测试数据，支持镉、铅、汞、铬、溴、氯检测
export function updateData(data) {
  return request({
    url: '/qc/data',
    method: 'put',
    data: data
  })
}

// 删除RoHS 测试数据，支持镉、铅、汞、铬、溴、氯检测
export function delData(id) {
  return request({
    url: '/qc/data/' + id,
    method: 'delete'
  })
}
// 新增RoHS 测试数据，支持镉、铅、汞、铬、溴、氯检测
export function refreshStatus() {
  return request({
    url: '/qc/data/refreshStatus',
    method: 'post'
  })
}
